@@ -7,6 +7,7 @@ from asn1crypto import cms, crl, x509
 from asn1crypto.crl import CRLReason
 from asn1crypto.keys import PublicKeyInfo
 from cryptography.exceptions import InvalidSignature
+
 from pyhanko_certvalidator._state import ValProcState
 from pyhanko_certvalidator.authority import (
     Authority,
@@ -39,10 +40,10 @@ from pyhanko_certvalidator.revinfo.archival import (
     RevinfoUsabilityRating,
 )
 from pyhanko_certvalidator.revinfo.manager import RevinfoManager
+from pyhanko_certvalidator.sig_validate import SignatureValidator
 from pyhanko_certvalidator.util import (
     ConsList,
     extract_ac_issuer_dir_name,
-    validate_sig,
 )
 
 OCSP_PROVENANCE_ERR = (
@@ -369,7 +370,10 @@ def _check_ocsp_status(
 
 
 def _verify_ocsp_signature(
-    responder_key: PublicKeyInfo, ocsp_response: OCSPContainer, errs: _OCSPErrs
+    responder_key: PublicKeyInfo,
+    ocsp_response: OCSPContainer,
+    sig_validator: SignatureValidator,
+    errs: _OCSPErrs,
 ) -> bool:
     response = ocsp_response.extract_basic_ocsp_response()
     if response is None:
@@ -378,12 +382,11 @@ def _verify_ocsp_signature(
     # Verify that the response was properly signed by the validated certificate
     tbs_response = response['tbs_response_data']
     try:
-        validate_sig(
+        sig_validator.validate_signature(
             signature=response['signature'].native,
             signed_data=tbs_response.dump(),
-            signed_digest_algorithm=response['signature_algorithm'],
             public_key_info=responder_key,
-            parameters=response['signature_algorithm']['parameters'],
+            signature_algorithm=response['signature_algorithm'],
         )
         return True
     except PSSParameterMismatch:
@@ -415,14 +418,6 @@ def _assess_ocsp_relevance(
     )
     if not responder_cert:
         return None
-
-    signature_ok = _verify_ocsp_signature(
-        responder_key=responder_cert.public_key,
-        ocsp_response=ocsp_response,
-        errs=errs,
-    )
-    if not signature_ok:
-        return None
     return responder_cert
 
 
@@ -444,7 +439,6 @@ async def _handle_single_ocsp_resp(
     )
     if responder_cert is None:
         return False
-
     freshness_result = ocsp_response.usable_at(
         policy=validation_context.revinfo_policy,
         timing_params=validation_context.timing_params,
@@ -452,7 +446,11 @@ async def _handle_single_ocsp_resp(
     rating = freshness_result.rating
     if rating != RevinfoUsabilityRating.OK:
         if rating == RevinfoUsabilityRating.STALE:
-            msg = 'OCSP response is not recent enough'
+            msg = (
+                f'OCSP response is not recent enough '
+                f'({freshness_result.compared_to} > '
+                f'{freshness_result.last_usable_at})'
+            )
             errs.update_stale(freshness_result.last_usable_at)
         elif rating == RevinfoUsabilityRating.TOO_NEW:
             msg = 'OCSP response is too recent'
@@ -461,6 +459,15 @@ async def _handle_single_ocsp_resp(
         errs.append(msg, ocsp_response, is_freshness_failure=True)
         return False
 
+    signature_ok = _verify_ocsp_signature(
+        responder_key=responder_cert.public_key,
+        ocsp_response=ocsp_response,
+        sig_validator=validation_context.sig_validator,
+        errs=errs,
+    )
+    if not signature_ok:
+        return False
+
     # check whether the responder cert is authorised
     authorised = await _check_ocsp_authorisation(
         responder_cert,
